==> ux-reward-wrap-2.0.6.tgz: package/lib/helper/index.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import "core-js/modules/es6.promise";
import "core-js/modules/es6.object.to-string";
import "regenerator-runtime/runtime";
import "core-js/modules/es6.regexp.match";
import "core-js/modules/es6.regexp.split";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import "core-js/modules/es6.array.find";
import "core-js/modules/es6.function.name";

/**
 * Created by liubo on 16/3/28.
 */
import objectAssign from 'object-assign';
import { debug } from 'util';
/**
 * 获取图片的完整路径
 * @return
 * //xfile4.tita.com/ux/tita-web-v5/release/dist/images/list-bg.png
 */

/*export GetStaticUrl=(url) =>{
  var staticServer = getBSGlobal('staticPath');
  return staticServer + "/images/" + url;
}*/

import featureUtils from '@beisen-cmps/feature-utils';
export function getBSGlobal(name) {
  return BSGlobal && BSGlobal[name];
}
export function GetStaticUrl(url) {
  var staticServer = getBSGlobal('staticPath');
  var staticServer = '//xfile4.tita.com/ux/uibuilder/release/extras/images';
  return staticServer + '/' + url;
} // 判断是否开通app

export function isOpenApp(appid) {
  var apps = getBSGlobal('apps') || [];
  var appItem = apps.find(function (item) {
    return item.appId == appid;
  });

  if (appItem) {
    // return true&&isOpenDoc;
    return true;
  } else {
    return false;
  }
}
export function takerCloud(_x, _x2, _x3) {
  return _takerCloud.apply(this, arguments);
}

function _takerCloud() {
  _takerCloud = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee(url, method, body) {
    var settings, contentType, response, data;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            settings = {};

            if (method) {
              contentType = method == 'POST' ? 'application/x-www-form-urlencoded' : 'application/json';
              settings.headers = {
                Accept: 'application/json, application/xml, text/play, text/html, *.*',
                'Content-Type': "".concat(contentType, "; charset=utf-8")
              };
              settings.method = method;
            }

            if (body) settings.body = JSON.stringify(body);
            settings.credentials = 'include';
            _context.prev = 4;
            _context.next = 7;
            return fetch(url, settings);

          case 7:
            response = _context.sent;
            _context.next = 10;
            return response.json();

          case 10:
            data = _context.sent;
            return _context.abrupt("return", data);

          case 14:
            _context.prev = 14;
            _context.t0 = _context["catch"](4);
            _context.next = 18;
            return Promise.reject('出错了');

          case 18:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, null, [[4, 14]]);
  }));
  return _takerCloud.apply(this, arguments);
}

export function taker(_x4, _x5, _x6) {
  return _taker.apply(this, arguments);
}
/**
 * 获取租户信息
 * @return
 * {"Id":200605,"Name":"wg","Domain":"abc.com","Abbreviation":"wg"}
 */

function _taker() {
  _taker = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee2(url, method, body) {
    var settings, response, data;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            settings = {};

            if (method) {
              settings.headers = {
                Accept: 'application/json, application/xml, text/play, text/html, *.*',
                'Content-Type': 'application/json; charset=utf-8'
              };
              settings.method = method;
            }

            if (body) settings.body = JSON.stringify(body);
            settings.credentials = 'same-origin';
            _context2.prev = 4;
            _context2.next = 7;
            return fetch(url, settings);

          case 7:
            response = _context2.sent;
            _context2.next = 10;
            return response.json();

          case 10:
            data = _context2.sent;
            return _context2.abrupt("return", data);

          case 14:
            _context2.prev = 14;
            _context2.t0 = _context2["catch"](4);
            _context2.next = 18;
            return Promise.reject('出错了');

          case 18:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2, null, [[4, 14]]);
  }));
  return _taker.apply(this, arguments);
}

export function getTenantInfo(url) {
  return getBSGlobal('tenantInfo');
}
/**
 * 获取当前登录用户信息
 * @return
 * {"Email":"wg1@abc.com","Avatar":"http://st-web.tita.com/titacn/tita/common/images/default_man_small.jpg","Id":100217545,"Name":"wg","IsRoot":false,"Role":3}
 */

export function getUserInfo(url) {
  return getBSGlobal('loginUserInfo');
}
/**
 * 获取后台接口的完整路径
 * @return
 * http://www.tita.com/api/v1/110006/100055587/page
 */

export function getApiUrl(url) {
  var uid = getUserInfo().Id;
  var tid = getTenantInfo().Id;
  var apiServer = getBSGlobal('apiPath');
  return apiServer + '/api/v1/' + tid + '/' + uid + '/' + url;
} //tita是否到期

export function getTitaExpire() {
  return BSGlobal.tenantAuthentication;
}
/**
 * 获取ITalentHome的地址
 * @return
 * http://www.tita.com/100055587/ITalentHome#home
 */

export function getItalentPathname(hash) {
  var titaHost = getBSGlobal('titaHost');
  var uid = getUserInfo().Id;
  return titaHost + '/' + uid + '/ITalentHome#' + hash;
}
/**
 * 获取后台接口的完整路径
 * @return
 * http://www.tita.com/api/v2/110006/100055587/page
 */

export function getApiUrl2(url) {
  var uid = getUserInfo().Id;
  var tid = getTenantInfo().Id;
  var apiServer = getBSGlobal('apiPath');
  return apiServer + '/api/v2/' + tid + '/' + uid + '/' + url;
}
export function getQueryString() {
  //获取Url上的参数，以{}返回
  var hash = location.hash;
  var queryObject = {};
  var markIndex = hash.indexOf('?'); // contain query string in fragments

  if (markIndex > -1) {
    // build query object
    var queryString = hash.slice(markIndex + 1);
    var queryArray = queryString.split('&');

    for (var i = 0; i < queryArray.length; i++) {
      var queryPair = queryArray[i].split('=');

      if (queryPair[0] !== '_k') {
        queryObject[queryPair[0]] = decodeURIComponent(queryPair[1]);
      }
    }
  }

  return queryObject;
} //检测字符数 一个汉字两个字符

export function getByteLen(val) {
  var len = 0;
  var en = 0; //英文数

  var cn = 0; //汉字数

  for (var i = 0; i < val.length; i++) {
    var a = val.charAt(i);

    if (a.match(/[^\x00-\xff]/gi) != null) {
      len += 2;
      ++cn;
    } else {
      len += 1;
      ++en;
    }
  }

  return {
    len: len,
    en: en,
    cn: cn
  };
}
export function getHeadColorById(id) {
  var color = ['#f0c75a', '#8dc8ea', '#7eb6e0', '#a1a5ee', '#c4a1ee', '#b9cc4f', '#96bf65', '#f79c6f', '#79c7b7', '#f5b168'];

  try {
    var idInt = parseInt(id);
    return color[idInt % 10];
  } catch (error) {
    console.error(error);
  }
}

function createUrl(url, frame) {
  var uid = getBSGlobal('loginUserInfo').Id;
  var apiPath = getBSGlobal('apiPath');
  var iframeBoxUrl = apiPath + '/' + uid + '/UpaasHome#' + encodeURIComponent(frame + encodeURIComponent(url));

  if (apiPath.indexOf('tita') > -1) {
    iframeBoxUrl = "".concat(apiPath, "/u/").concat(uid, "/Home#").concat(encodeURIComponent(frame + encodeURIComponent(url)));
  }

  if (apiPath.indexOf('italent') > -1) {
    iframeBoxUrl = "".concat(apiPath, "/").concat(uid, "/ITalentHome#").concat(encodeURIComponent(frame + encodeURIComponent(url)));
  }

  return iframeBoxUrl;
}

export function encodeURIFn(url) {
  return createUrl(url, 'widget/italent?iTalentFrame=');
} // 只要头部栏

export function encodeURIFnTop(url) {
  return createUrl(url, 'widget/italent-no-sidebar?iTalentFrame=');
}
export function encodeURIFnWidget(url) {
  return createUrl(url, 'widget/italent?iTalentFrameType=iframe&iTalentFrame=');
}
export function urlHead() {
  var apiServer = getBSGlobal('apiPath');
  var uid = getBSGlobal('loginUserInfo').Id;
  var webPath = getBSGlobal('webPath');
  var urlHead = '//www' + webPath + '/' + uid + '/UpaasHome';

  if (webPath.indexOf('tita') > -1) {
    urlHead = "//www.".concat(webPath, "/u/").concat(uid, "/Home");
  }

  if (webPath.indexOf('italent') > -1) {
    urlHead = "//www.".concat(webPath, "/").concat(uid, "/ITalentHome");
  }

  return urlHead;
} // 获取to_user_id

export function getToUserId() {
  var toUserId = getQueryString().to_user_id;

  if (!toUserId) {
    toUserId = getUserInfo().Id;
  }

  return toUserId;
} //加载打赏组件

export function loadRewardPop() {
  var features_version = window.__italent_common_cmps__ && window.__italent_common_cmps__.features_version || '';
  var version = features_version || '1.3.45';

  if (!document.getElementById('reward-css')) {
    var link = document.createElement('link');
    link.type = 'text/css';
    link.id = 'reward-css';
    link.href = "//stnew03.beisen.com/ux/upaas/reward/release/dist/main-".concat(version, ".min.css");
    link.rel = 'stylesheet';
    document.body.appendChild(link);
  }

  if (!document.getElementById('reward-js')) {
    var script = document.createElement('script');
    script.type = 'text/javascript';
    script.id = 'reward-js';
    script.src = "//stnew03.beisen.com/ux/upaas/reward/release/dist/main-".concat(version, ".min.js");
    document.body.appendChild(script);
  }

  if (!document.getElementById('reward-wrap')) {
    var div = document.createElement('div');
    div.id = 'reward-wrap';
    document.body.appendChild(div);
  }
} //首页打赏组件调用打赏弹窗

export function goReward() {
  //调用打赏弹层
  featureUtils.call({
    type: 'renderPayReward',
    params: {
      needMask: true,
      //不传的话 就是有
      objId: '',
      objType: 1
    }
  }); // if (!window.Features) return;
  // const Features = window.Features || {};
  // const { Name, UserAvatar, Id } = getUserInfo();
  // const myReward = new Features({
  //     needMask: false,
  //     zIndex: 99999999, //层级
  //     changeLeftMenuShade: true,
  //     onClose: function() {
  //         //关闭的回调
  //     },
  //     onSuccess: function() {
  //         //打赏成功的回掉函数
  //     },
  //     domNode: document.getElementById("reward-wrap"), //组件的挂载点
  //     loginUser: {
  //         //当前登陆账号的信息
  //         name: Name,
  //         avatar: {
  //             hasAvatar: UserAvatar.HasAvatar,
  //             img: UserAvatar.Small,
  //             color: UserAvatar.Color
  //         },
  //         id: Id
  //     }
  // });
  // myReward.renderPayReward({
  //     needMask: true, //不传的话 就是有
  //     objId: "",
  //     objType: 1
  // });
} //判断是否是tita

export function isTita() {
  return getBSGlobal('isv') == '10000' || getBSGlobal('ISVType') == '10000';
}
export function getAppCenterApiUrl(url) {
  var env = getBSGlobal('env');
  var staticMap = ['//appcenter.italen-inc.cn', '//appcenter.italent.link', '//appcenter.italent.cn'];

  switch (env) {
    case 'Development':
      //开发develop
      return staticMap[0] + url;

    case 'develop':
      return staticMap[0] + url;

    case 'Production':
      //线上
      return staticMap[2] + url;

    case 'Testing':
      return staticMap[1] + url;

    default:
      return staticMap[2] + url;
  }
}

==> ux-reward-wrap-3.0.3.tgz: package/lib/helper/index.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import "core-js/modules/es6.promise";
import "core-js/modules/es6.object.to-string";
import "regenerator-runtime/runtime";
import "core-js/modules/es6.regexp.match";
import "core-js/modules/es6.regexp.split";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import "core-js/modules/es6.array.find";
import "core-js/modules/es6.function.name";

/**
 * Created by liubo on 16/3/28.
 */
import objectAssign from 'object-assign';
import BSHelper from '@beisen/helper';
/**
 * 获取图片的完整路径
 * @return
 * //xfile4.tita.com/ux/tita-web-v5/release/dist/images/list-bg.png
 */

/*export GetStaticUrl=(url) =>{
  var staticServer = getBSGlobal('staticPath');
  return staticServer + "/images/" + url;
}*/

import featureUtils from '@beisen-cmps/feature-utils';
export function getBSGlobal(name) {
  return BSGlobal && BSGlobal[name];
}
export function GetStaticUrl(url) {
  var staticServer = getBSGlobal('staticPath');
  var staticServer = '//xfile4.tita.com/ux/uibuilder/release/extras/images';
  return staticServer + '/' + url;
} // 判断是否开通app

export function isOpenApp(appid) {
  var apps = getBSGlobal('apps') || [];
  var appItem = apps.find(function (item) {
    return item.appId == appid;
  });

  if (appItem) {
    // return true&&isOpenDoc;
    return true;
  } else {
    return false;
  }
}
export function takerCloud(_x, _x2, _x3) {
  return _takerCloud.apply(this, arguments);
}

function _takerCloud() {
  _takerCloud = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee(url, method, body) {
    var settings, contentType, response, data;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            settings = {};

            if (method) {
              contentType = method == 'POST' ? 'application/x-www-form-urlencoded' : 'application/json';
              settings.headers = {
                Accept: 'application/json, application/xml, text/play, text/html, *.*',
                'Content-Type': "".concat(contentType, "; charset=utf-8")
              };
              settings.method = method;
            }

            if (body) settings.body = JSON.stringify(body);
            settings.credentials = 'include';
            _context.prev = 4;
            _context.next = 7;
            return fetch(url, settings);

          case 7:
            response = _context.sent;
            _context.next = 10;
            return response.json();

          case 10:
            data = _context.sent;
            return _context.abrupt("return", data);

          case 14:
            _context.prev = 14;
            _context.t0 = _context["catch"](4);
            _context.next = 18;
            return Promise.reject('出错了');

          case 18:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, null, [[4, 14]]);
  }));
  return _takerCloud.apply(this, arguments);
}

export function taker(_x4, _x5, _x6) {
  return _taker.apply(this, arguments);
}
/**
 * 获取租户信息
 * @return
 * {"Id":200605,"Name":"wg","Domain":"abc.com","Abbreviation":"wg"}
 */

function _taker() {
  _taker = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee2(url, method, body) {
    var settings, response, data;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            settings = {};

            if (method) {
              settings.headers = {
                Accept: 'application/json, application/xml, text/play, text/html, *.*',
                'Content-Type': 'application/json; charset=utf-8'
              };
              settings.method = method;
            }

            if (body) settings.body = JSON.stringify(body);
            settings.credentials = 'same-origin';
            _context2.prev = 4;
            _context2.next = 7;
            return fetch(url, settings);

          case 7:
            response = _context2.sent;
            _context2.next = 10;
            return response.json();

          case 10:
            data = _context2.sent;
            return _context2.abrupt("return", data);

          case 14:
            _context2.prev = 14;
            _context2.t0 = _context2["catch"](4);
            _context2.next = 18;
            return Promise.reject('出错了');

          case 18:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2, null, [[4, 14]]);
  }));
  return _taker.apply(this, arguments);
}

export function getTenantInfo(url) {
  return getBSGlobal('tenantInfo');
}
/**
 * 获取当前登录用户信息
 * @return
 * {"Email":"wg1@abc.com","Avatar":"http://st-web.tita.com/titacn/tita/common/images/default_man_small.jpg","Id":100217545,"Name":"wg","IsRoot":false,"Role":3}
 */

export function getUserInfo(url) {
  return getBSGlobal('loginUserInfo');
}
/**
 * 获取后台接口的完整路径
 * @return
 * http://www.tita.com/api/v1/110006/100055587/page
 */

export function getApiUrl(url) {
  var uid = getUserInfo().Id;
  var tid = getTenantInfo().Id;
  var apiServer = getBSGlobal('apiPath');
  return apiServer + '/api/v1/' + tid + '/' + uid + '/' + url;
} //tita是否到期

export function getTitaExpire() {
  return BSGlobal.tenantAuthentication;
}
/**
 * 获取ITalentHome的地址
 * @return
 * http://www.tita.com/100055587/ITalentHome#home
 */

export function getItalentPathname(hash) {
  var titaHost = getBSGlobal('titaHost');
  var uid = getUserInfo().Id;
  return titaHost + '/' + uid + '/ITalentHome#' + hash;
}
/**
 * 获取后台接口的完整路径
 * @return
 * http://www.tita.com/api/v2/110006/100055587/page
 */

export function getApiUrl2(url) {
  var uid = getUserInfo().Id;
  var tid = getTenantInfo().Id;
  var apiServer = getBSGlobal('apiPath');
  return apiServer + '/api/v2/' + tid + '/' + uid + '/' + url;
}
export function getQueryString() {
  //获取Url上的参数，以{}返回
  var hash = location.hash;
  var queryObject = {};
  var markIndex = hash.indexOf('?'); // contain query string in fragments

  if (markIndex > -1) {
    // build query object
    var queryString = hash.slice(markIndex + 1);
    var queryArray = queryString.split('&');

    for (var i = 0; i < queryArray.length; i++) {
      var queryPair = queryArray[i].split('=');

      if (queryPair[0] !== '_k') {
        queryObject[queryPair[0]] = decodeURIComponent(queryPair[1]);
      }
    }
  }

  return queryObject;
} //检测字符数 一个汉字两个字符

export function getByteLen(val) {
  var len = 0;
  var en = 0; //英文数

  var cn = 0; //汉字数

  for (var i = 0; i < val.length; i++) {
    var a = val.charAt(i);

    if (a.match(/[^\x00-\xff]/gi) != null) {
      len += 2;
      ++cn;
    } else {
      len += 1;
      ++en;
    }
  }

  return {
    len: len,
    en: en,
    cn: cn
  };
}
export function getHeadColorById(id) {
  var color = ['#f0c75a', '#8dc8ea', '#7eb6e0', '#a1a5ee', '#c4a1ee', '#b9cc4f', '#96bf65', '#f79c6f', '#79c7b7', '#f5b168'];

  try {
    var idInt = parseInt(id);
    return color[idInt % 10];
  } catch (error) {
    console.error(error);
  }
}

function createUrl(url, frame) {
  var uid = getBSGlobal('loginUserInfo').Id;
  var apiPath = getBSGlobal('apiPath');
  var iframeBoxUrl = apiPath + '/' + uid + '/UpaasHome#' + encodeURIComponent(frame + encodeURIComponent(url));

  if (apiPath.indexOf('tita') > -1) {
    iframeBoxUrl = "".concat(apiPath, "/u/").concat(uid, "/Home#").concat(encodeURIComponent(frame + encodeURIComponent(url)));
  }

  if (apiPath.indexOf('italent') > -1) {
    iframeBoxUrl = "".concat(apiPath, "/").concat(uid, "/ITalentHome#").concat(encodeURIComponent(frame + encodeURIComponent(url)));
  }

  return iframeBoxUrl;
}

export function encodeURIFn(url) {
  return createUrl(url, 'widget/italent?iTalentFrame=');
} // 只要头部栏

export function encodeURIFnTop(url) {
  return createUrl(url, 'widget/italent-no-sidebar?iTalentFrame=');
}
export function encodeURIFnWidget(url) {
  return createUrl(url, 'widget/italent?iTalentFrameType=iframe&iTalentFrame=');
}
export function urlHead() {
  var apiServer = getBSGlobal('apiPath');
  var uid = getBSGlobal('loginUserInfo').Id;
  var webPath = getBSGlobal('webPath');
  var urlHead = '//www' + webPath + '/' + uid + '/UpaasHome';

  if (webPath.indexOf('tita') > -1) {
    urlHead = "//www.".concat(webPath, "/u/").concat(uid, "/Home");
  }

  if (webPath.indexOf('italent') > -1) {
    urlHead = "//www.".concat(webPath, "/").concat(uid, "/ITalentHome");
  }

  return urlHead;
} // 获取to_user_id

export function getToUserId() {
  var toUserId = getQueryString().to_user_id;

  if (!toUserId) {
    toUserId = getUserInfo().Id;
  }

  return toUserId;
} //加载打赏组件

export function loadRewardPop() {
  var features_version = window.__italent_common_cmps__ && window.__italent_common_cmps__.features_version || '';
  var version = features_version || '1.3.45';

  if (!document.getElementById('reward-css')) {
    var link = document.createElement('link');
    link.type = 'text/css';
    link.id = 'reward-css';
    link.href = "//stnew03.beisen.com/ux/upaas/reward/release/dist/main-".concat(version, ".min.css");
    link.rel = 'stylesheet';
    document.body.appendChild(link);
  }

  if (!document.getElementById('reward-js')) {
    var script = document.createElement('script');
    script.type = 'text/javascript';
    script.id = 'reward-js';
    script.src = "//stnew03.beisen.com/ux/upaas/reward/release/dist/main-".concat(version, ".min.js");
    document.body.appendChild(script);
  }

  if (!document.getElementById('reward-wrap')) {
    var div = document.createElement('div');
    div.id = 'reward-wrap';
    document.body.appendChild(div);
  }
} //首页打赏组件调用打赏弹窗

export function goReward() {
  //调用打赏弹层
  featureUtils.call({
    type: 'renderPayReward',
    params: {
      needMask: true,
      //不传的话 就是有
      objId: '',
      objType: 1
    }
  }); // if (!window.Features) return;
  // const Features = window.Features || {};
  // const { Name, UserAvatar, Id } = getUserInfo();
  // const myReward = new Features({
  //     needMask: false,
  //     zIndex: 99999999, //层级
  //     changeLeftMenuShade: true,
  //     onClose: function() {
  //         //关闭的回调
  //     },
  //     onSuccess: function() {
  //         //打赏成功的回掉函数
  //     },
  //     domNode: document.getElementById("reward-wrap"), //组件的挂载点
  //     loginUser: {
  //         //当前登陆账号的信息
  //         name: Name,
  //         avatar: {
  //             hasAvatar: UserAvatar.HasAvatar,
  //             img: UserAvatar.Small,
  //             color: UserAvatar.Color
  //         },
  //         id: Id
  //     }
  // });
  // myReward.renderPayReward({
  //     needMask: true, //不传的话 就是有
  //     objId: "",
  //     objType: 1
  // });
}
export var isvId = getBSGlobal('ISVType') || getBSGlobal('isv') || '10001';
export function getAppCenterApiUrl(url) {
  // const env = getBSGlobal('env');
  // const staticMap = [
  //   '//appcenter.italen-inc.cn',
  //   '//appcenter.italent.link',
  //   '//appcenter.italent.cn',
  // ];
  // switch (env) {
  //   case 'Development': //开发develop
  //     return staticMap[0] + url;
  //   case 'develop':
  //     return staticMap[0] + url;
  //   case 'Production': //线上
  //     return staticMap[2] + url;
  //   case 'Testing':
  //     return staticMap[1] + url;
  //   default:
  //     return staticMap[2] + url;
  // }
  return "".concat(BSHelper.getHostByType('appcenter')).concat(url);
} //判断是否是tita

export function isTita() {
  return getBSGlobal('isv') == '10000' || getBSGlobal('ISVType') == '10000';
}
export var bountyManagementLink = "".concat(getBSGlobal('titaHost'), "/").concat(getUserInfo().Id, "/BountySetting#/");
